
# Azure Synapse Artifacts client library for Python Samples

These are code samples that show common scenario operations with the Azure Synapse Artifacts client library.

## Prerequisites

* Python 3.6 or later is required to use this package
* You need an [Azure subscription][azure_sub] to use this package.

## Setup

1. Install the Azure Synapse Artifacts client library for Python with [pip](https://pypi.org/project/pip/):

```bash
pip install azure-identity
pip install azure-synapse-artifacts
```

2. Clone or download this sample repository
3. Open the sample folder in Visual Studio Code or your IDE of choice.

## Running the samples

1. Open a terminal window and `cd` to the directory that the samples are saved in.
2. Set the environment variables specified in the sample file you wish to run.
3. Follow the usage described in the file, e.g. `python simple_sample.py`

<!-- LINKS -->
[azure_sub]: https://azure.microsoft.com/free/
